@@ -13,9 +13,9 @@ class DefaultMiddleware(Middleware):
 
 class DefaultExceptionHandler:
     def __init__(self, app):
-        self.app = app(templates_dir="selfpages")
+        self.app = app
 
     def handle_error(self, request, response, error):
         response.status_code = 500
-        response.body = self.app.template(
-            "error-500.html", context={"error": str(error)})
+        response.body = self.app.custom_template("selfpages"
+                                                 "error-500.html", context={"error": str(error)})
